pub enum FixMode {
Off,
Apply,
DryRun,
}Expand description
Whether — and how — lint_files_with_options should apply auto-fixes.
Variants
Off
Read-only: do not attempt to fix anything.
Apply
Apply fixes in memory and write them back to disk.
DryRun
Compute the fixes that would be applied but don’t write any files.