pub fn warn(msg: impl AsRef<str>)Expand description
Emit a warning message to stderr.
- If quiet mode is active the message is silently discarded.
- If the identical message has already been printed once, it is counted as suppressed rather than re-printed.
- If
inithas not been called yet the message is always printed and dedup tracking is skipped (the dedup map is not yet initialised).